@@ -85,31 +85,28 @@ class DedimaniaAPI:
 				self.retries = 0
 				return data[0]
 			raise DedimaniaTransportException('Invalid response from dedimania!')
-		except (
-			ConnectionError, ReadTimeout, ConnectionRefusedError, requests.exceptions.ConnectionError, ConnectTimeout,
-			DedimaniaTransportException
-		) as e:
+		except (ConnectionError, ReadTimeout, ConnectionRefusedError, requests.exceptions.ConnectionError) as e:
+			raise DedimaniaTransportException(e) from e
+		except ConnectTimeout as e:
+			raise DedimaniaTransportException(e) from e
+		except DedimaniaTransportException:
 			# Try to setup new session.
 			self.retries += 1
-			if self.retries > 2:
-				self.retries = 0
-				raise DedimaniaTransportException(
-					'Dedimania didn\'t gave the right answer after few retries! Max retries reached.'
-				) from e
+			if self.retries > 5:
+				raise DedimaniaTransportException('Dedimania didn\'t gave the right answer after few retries!')
 			self.client = requests.session()
-			logger.warning('Dedimania timeout, doing a retry (retry {} of {})'.format(self.retries, 3))
 			try:
 				await self.authenticate()
 				return await self.execute(method, *args)
-			except Exception as e2:
-				logger.error('XML-RPC Fault retrieved from Dedimania: {}'.format(str(e2)))
+			except Exception as e:
+				logger.error('XML-RPC Fault retrieved from Dedimania: {}'.format(str(e)))
 				handle_exception(e, __name__, 'execute')
-				raise DedimaniaTransportException('Could not retrieve data from dedimania!') from e2
+				raise DedimaniaTransportException('Could not retrieve data from dedimania!')
 		except DedimaniaFault as e:
 			if 'Bad SessionId' in e.faultString or ('SessionId' in e.faultString and 'not found' in e.faultString):
 				try:
 					self.retries += 1
-					if self.retries > 2:
+					if self.retries > 5:
 						raise DedimaniaTransportException('Max retries reached for reauthenticating with dedimania!')
 
 					# Save original session ID.
@@ -188,11 +185,13 @@ class DedimaniaAPI:
 			player_list = [
 				{'Login': p['Login'], 'IsSpec': is_spectator(p), 'Vote': -1} for p in players if p['Login'] != self.instance.game.server_player_login
 			]
+
 			num_specs = sum(p['IsSpec'] for p in player_list)
 			num_players = len(player_list) - num_specs
-			max_players = self.instance.game.server_max_players['CurrentValue']
-			max_specs = self.instance.game.server_max_specs['CurrentValue']
+			max_players = self.instance.player_manager.max_players
+			max_specs = self.instance.player_manager.max_spectators
 			mode = self.mode_to_dedi_mode(await self.instance.mode_manager.get_current_script())
+
 			if not mode:
 				continue
 			try:
