@@ -3,7 +3,7 @@ from pyplanet.views.generics.widget import WidgetView
 
 
 class SectorTimesWidget(WidgetView):
-	widget_x = 20
+	# widget_x = 20
 	widget_y = -70
 
 	template_name = 'sector_times/sector_times.xml'
@@ -18,6 +18,13 @@ class SectorTimesWidget(WidgetView):
 		self.manager = app.context.ui
 		self.id = 'pyplanet__widgets_sector_times'
 
+	@property
+	def widget_x(self):
+		if self.app:
+			if self.app.instance.game.game == 'tmnext':
+				return -55
+		return 20
+
 	async def get_per_player_data(self, login):
 		dedi_score = 0
 		dedi_record = None
@@ -63,6 +70,8 @@ class SectorTimesWidget(WidgetView):
 		context['record_sector_times'] = fastest_cps
 		context['record_time'] = fastest_score
 		context['record_source'] = fastest_source
+		if not fastest_cps:
+			context['record_time'] = 0
 
 		return context
 
@@ -126,6 +135,8 @@ class CheckpointDiffWidget(WidgetView):
 		context['record_sector_times'] = fastest_cps
 		context['record_time'] = fastest_score
 		context['record_source'] = fastest_source
+		if not fastest_cps:
+			context['record_time'] = 0
 
 		return context
 
